@@ -1,4 +1,4 @@
-nominal_discrete.changes = function(model, values, data, position=1, sim.count=1000, conf.int=0.95, sigma=NULL){
+nominal_discrete.changes = function(model, values, data, position=1, sim.count=1000, conf.int=0.95, sigma=NULL,set.seed=NULL){
   if(!is.character(values)){
     stop("values must be given as character!")
   }
@@ -122,7 +122,7 @@ nominal_discrete.changes = function(model, values, data, position=1, sim.count=1
         pos = pos + 2
       }
     }
-    subresult = nominal_discrete.change(model,row.values1,row.values2,sim.count,conf.int,sigma)
+    subresult = nominal_discrete.change(model,row.values1,row.values2,sim.count,conf.int,sigma,set.seed)
     
       for(k in 1:n.levels){
         current.row = (r-1)*n.levels + k
@@ -189,7 +189,7 @@ getValues_nominal = function(model,values,formula,data){
         if(is.numeric(mode)){
           current.values = mode
         }else{
-          n = length(levels(data.v))
+          n = length(levels(as.factor(as.character(data.v))))
           dummies = getDummies(n)
           current.values = matrix(dummies[which(levels(data.v)==mode),],nrow=1)
           is.factor[pos] = T
@@ -249,7 +249,7 @@ getValues_nominal = function(model,values,formula,data){
       components = as.numeric(unlist(strsplit(value,"[F\\(\\)]")))
       varName = formula[pos]
       data.v = data[,varName]
-      n = length(levels(data.v))
+      n = length(levels(as.factor(as.character(data.v))))
       x = components[3]
       dummies = getDummies(n)
       current.values = matrix(dummies[x,],nrow=1)
@@ -263,7 +263,7 @@ getValues_nominal = function(model,values,formula,data){
     else if(grepl("^F$",value,ignore.case = TRUE)){ # factor
       varName = formula[pos]
       data.v = data[,varName]
-      n = length(levels(data.v))
+      n = length(levels(as.factor(as.character(data.v))))
       current.values = getDummies(n)
       is.factor[pos] = T
     } # factor
@@ -336,25 +336,6 @@ getProducts_dc = function(value,position){
   return(results)
 }
 
-getDummies = function(n){
-  if(n == 2){
-    return(matrix(0:1,nrow=2,ncol=1))
-  }
-  n = n-1
-  I = iterpc::iterpc(2, n, label=c(0,1), order=T, replace=T)
-  grid = iterpc::getall(I)
-  grid = grid[order(rowSums(grid)),]
-  grid = subset(grid,rowSums(grid)<=1)
-  grid = grid[,n:1]
-  return(grid)
-}
-
-getCombinations = function(n){
-  I = iterpc::iterpc(n, 2)
-  grid = iterpc::getall(I)
-  return(grid)
-}
-
 getNames_dc = function(names,position){
   new.names = c("mean1","mean2","lower1","upper1","lower2","upper2","mean.diff","lower.diff","upper.diff")
   for(i in 1:length(names)){
@@ -371,7 +352,7 @@ getNames_dc = function(names,position){
 
 getLabel_nominal = function(model,varName,pos,data){
   data.v = data[,grep(varName,colnames(data),value=T)[1]]
-  labels = levels(data.v)
+  labels = levels(as.factor(as.character(data.v)))
   return(labels[pos])
 }
 
